==> haskell-dav-1.3.3-54-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-dav.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: DAV
version: 1.3.3
id: DAV-1.3.3-3Hdx3O3EP0351omAwqAecB
key: DAV-1.3.3-3Hdx3O3EP0351omAwqAecB
license: GPL-3.0-only
copyright: Copyright (C) 2012-2018  Clint Adams
maintainer: clint@debian.org
author: Clint Adams
homepage: http://floss.scru.org/hDAV
synopsis: RFC 4918 WebDAV support
description:
    This is a library for the Web Distributed Authoring and Versioning
    (WebDAV) extensions to HTTP.  At present it supports a very small
    subset of client functionality.
    .
    In addition, there is an executable, hdav, which can be used for
    command-line operation.
category: Web
abi: c85b33f6c0765bf11fe0127b54f8c3c4
exposed: True
exposed-modules:
    Network.Protocol.HTTP.DAV
hidden-modules: Network.Protocol.HTTP.DAV.TH
import-dirs: /usr/lib/ghc-8.6.5/site-local/DAV-1.3.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/DAV-1.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/DAV-1.3.3
hs-libraries: HSDAV-1.3.3-3Hdx3O3EP0351omAwqAecB
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk containers-0.6.0.1
    data-default-0.7.1.1-GPAEdZkaAwALFGM1Pbeyt4
    exceptions-0.10.2-6GSxCzaG9kmCGyegXlyMgA
    http-client-0.6.4-2AUqtuWNJg2Xt7IT49doi
    http-client-tls-0.3.5.3-KFp4luqa2zBAhetN3GU6ly
    http-types-0.12.3-Ge4lCiHP3W4Hc9xNIKz9xs
    lens-4.17.1-Js1yrLTeu5QBhIoEtEZIyW mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.5.2-KiogS5KFFp4IwxvJXTI1QL
    transformers-compat-0.6.4-3mIoeQKAFq789cuQC8bUpt
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
    xml-conduit-1.8.0.1-ILvF71FlHvVFNoTnSo3FAD
    xml-hamlet-0.5.0-7yV0NGWHKCCgIZ8MvDUor
haddock-interfaces: /usr/share/doc/haskell-dav/html/DAV.haddock
haddock-html: /usr/share/doc/haskell-dav/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dav-1.3.3-55-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-dav.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: DAV
version: 1.3.3
id: DAV-1.3.3-61SKRjes85vDDfKFzMWgcj
key: DAV-1.3.3-61SKRjes85vDDfKFzMWgcj
license: GPL-3.0-only
copyright: Copyright (C) 2012-2018  Clint Adams
maintainer: clint@debian.org
author: Clint Adams
homepage: http://floss.scru.org/hDAV
synopsis: RFC 4918 WebDAV support
description:
    This is a library for the Web Distributed Authoring and Versioning
    (WebDAV) extensions to HTTP.  At present it supports a very small
    subset of client functionality.
    .
    In addition, there is an executable, hdav, which can be used for
    command-line operation.
category: Web
abi: f23fac3dcdd6156f60b3d4fc7d82d9b0
exposed: True
exposed-modules:
    Network.Protocol.HTTP.DAV
hidden-modules: Network.Protocol.HTTP.DAV.TH
import-dirs: /usr/lib/ghc-8.6.5/site-local/DAV-1.3.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/DAV-1.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/DAV-1.3.3
hs-libraries: HSDAV-1.3.3-61SKRjes85vDDfKFzMWgcj
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk containers-0.6.0.1
    data-default-0.7.1.1-GPAEdZkaAwALFGM1Pbeyt4
    exceptions-0.10.2-6GSxCzaG9kmCGyegXlyMgA
    http-client-0.6.4-2AUqtuWNJg2Xt7IT49doi
    http-client-tls-0.3.5.3-KFp4luqa2zBAhetN3GU6ly
    http-types-0.12.3-Ge4lCiHP3W4Hc9xNIKz9xs
    lens-4.17.1-Ens6S9QgklhL5TIdxTAVwy mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.5.2-KiogS5KFFp4IwxvJXTI1QL
    transformers-compat-0.6.4-3mIoeQKAFq789cuQC8bUpt
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
    xml-conduit-1.8.0.1-3BC9flIY0M3GLhkbgKhU6a
    xml-hamlet-0.5.0-40fDUQqYixf6rytRwezxva
haddock-interfaces: /usr/share/doc/haskell-dav/html/DAV.haddock
haddock-html: /usr/share/doc/haskell-dav/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
